@@ -1,22 +1,54 @@
 import sys
 import click
 import uuid
+import jmespath
+import os
+from cloudscale import CloudscaleApiException
 
 @click.group()
 @click.pass_context
 def server(ctx):
-    ctx.obj.cloud_resource_name = "server"
-    ctx.obj.headers = [
+
+    headers = [
+        'name',
+        'status',
+        'zone',
+        'tags',
+        'uuid',
+    ]
+
+    verbose_headers = [
         'name',
         'image',
         'flavor',
-        'zone',
-        'tags',
-        'server_groups',
-        'uuid',
         'status',
+        'zone',
+        'public_ips',
+        'private_ips',
+        'server_groups',
+        'volumes',
+        'tags',
+        'uuid',
     ]
 
+    ctx.obj.cloud_resource_name = "server"
+    ctx.obj.headers = verbose_headers if ctx.obj.verbose else headers
+    ctx.obj.response_transform_json = '''
+        [].{
+            "name": name,
+            "image": image.slug,
+            "flavor": flavor.slug,
+            "tags": tags,
+            "server_groups": server_groups,
+            "volumes": volumes[].name,
+            "public_ips": interfaces[?type=='public'].addresses[].address,
+            "private_ips": interfaces[?type=='private'].addresses[].address,
+            "zone": zone.slug,
+            "status": status,
+            "uuid": uuid
+            }
+    '''
+
 @click.option('--filter-tag')
 @click.option('--filter-json')
 @click.option('--action', type=click.Choice(['start', 'stop', 'reboot']))
@@ -165,3 +197,50 @@ def cmd_reboot(cloudscale, uuid):
         action="reboot",
         uuid=uuid,
     )
+
+@click.argument('uuid', required=True)
+@click.option('--interface', type=click.Choice(['public', 'private']), default='public', show_default=True)
+@server.command("ssh")
+@click.pass_obj
+def cmd_ssh(cloudscale, uuid, interface):
+    try:
+        response = cloudscale.get_client_resource().get_by_uuid(uuid)
+    except CloudscaleApiException as e:
+        results = cloudscale.cmd_get_by_name(name=uuid)
+        if not results:
+            if cloudscale.resource_name_key:
+                msg = f"No resource found for {cloudscale.cloud_resource_name} having UUID or {cloudscale.resource_name_key}: {uuid}"
+            else:
+                msg = f"No resource found for {cloudscale.cloud_resource_name} having UUID: {uuid}"
+            click.echo(msg, err=True)
+            sys.exit(1)
+
+        if len(results) > 1:
+            click.echo(f"Error: More than one resource found for {cloudscale.cloud_resource_name} having name: {uuid}. Use UUID to update.", err=True)
+            sys.exit(1)
+
+    except Exception as e:
+        click.echo(e, err=True)
+        sys.exit(1)
+
+    try:
+        response = results[0]
+        filter_json = '''
+            {
+            "public": interfaces[?type=='public'].addresses[0].address,
+            "private": interfaces[?type=='private'].addresses[0].address,
+            "username": image.default_username
+            }
+        '''
+        response = jmespath.search(filter_json, response)
+        for host in response[interface]:
+            ssh_cmd = f"ssh {response['username']}@{host}"
+            os.system(ssh_cmd)
+            break
+        else:
+            click.echo(f"No IP on interface found: {interface}", err=True)
+            sys.exit(1)
+
+    except Exception as e:
+        click.echo(e, err=True)
+        sys.exit(1)
